Fashion

Fashion is a command line utility for simple model transformation and source code generation, aimed at a target audience of developers.

See https://github.com/braddillman/fashion for more details.
